@@ -20,6 +20,33 @@ NULL
 # @aliases get set
 # NULL
 
+#' Labels
+#'
+#' Find a suitable set of labels from an object.
+#' @param object An \R object.
+#' @param ... Currently not used.
+#' @return
+#'  A [`character`] vector.
+#' @author N. Frerebeau
+#' @docType methods
+#' @family mutators
+#' @name labels
+#' @rdname labels
+NULL
+
+#' Length
+#'
+#' Get the length of an object.
+#' @param x An \R object.
+#' @return
+#'  A length-one [`integer`] vector.
+#' @author N. Frerebeau
+#' @docType methods
+#' @family mutators
+#' @name length
+#' @rdname length
+NULL
+
 ## Subset ----------------------------------------------------------------------
 #' Extract or Replace Parts of an Object
 #'
@@ -42,6 +69,23 @@ NULL
 #' @rdname subset
 NULL
 
+## Coerce ----------------------------------------------------------------------
+#' Coerce to a Data Frame
+#'
+#' @param x A [`TimeSeries-class`] or a [`TimeIntervals-class`] object.
+#' @param calendar A [`TimeScale-class`] object specifying the target calendar
+#'  (see [calendar()]). If `NULL` (the default), *rata die* are returned.
+#' @param ... Further parameters to be passed to [data.frame()].
+#' @return
+#'  A [`data.frame`].
+#' @example inst/examples/ex-series.R
+#' @author N. Frerebeau
+#' @docType methods
+#' @family mutators
+#' @name as.data.frame
+#' @rdname as.data.frame
+NULL
+
 # Calendars ====================================================================
 #' Calendar
 #'
@@ -471,7 +515,7 @@ NULL
 #' @example inst/examples/ex-series.R
 #' @author N. Frerebeau
 #' @docType methods
-#' @family time series tools
+#' @family time series
 #' @aliases series-method
 setGeneric(
   name = "series",
@@ -479,24 +523,54 @@ setGeneric(
   valueClass = "TimeSeries"
 )
 
-#' Terminal Times of Time Series
+# Time Intervals ===============================================================
+#' Create Time Intervals
+#'
+#' An Interval is elapsed time in seconds between two specific years.
+#' @param start A [`numeric`] vector of (decimal) years or a [`RataDie-class`]
+#'  object (see [fixed()]) giving the beginning of the time intervals.
+#' @param end A [`numeric`] vector of (decimal) years or a [`RataDie-class`]
+#'  object (see [fixed()]) giving the end of the time intervals.
+#' @param calendar A [`TimeScale-class`] object specifying the calendar of
+#'  `time` (see [calendar()]). If missing, `time` must be a [`RataDie-class`]
+#'  object.
+#' @param scale A length-one [`numeric`] vector specifying the number of years
+#'  represented by one unit. It should be a power of 10 (i.e. 1000 means ka).
+#' @param names A [`character`] string specifying the names of the time
+#'  series.
+#' @param ... Currently not used.
+#' @return
+#'  A [`TimeIntervals-class`] object.
+#' @example inst/examples/ex-intervals.R
+#' @author N. Frerebeau
+#' @docType methods
+#' @family time intervals
+#' @aliases intervals-method
+setGeneric(
+  name = "intervals",
+  def = function(start, end, calendar, ...) standardGeneric("intervals"),
+  valueClass = "TimeIntervals"
+)
+
+# Tools ========================================================================
+#' Terminal Times
 #'
 #' Get the times the first and last observations were taken.
 #' @param x A [`TimeSeries-class`] object.
 #' @param calendar A [`TimeScale-class`] object specifying the target calendar
 #'  (see [calendar()]). If `NULL` (the default), *rata die* are returned.
 #' @return
-#'  A [`numeric`] vector.
+#'  A [`numeric`] vector of decimal years (if `calendar` is not `NULL`).
 #' @example inst/examples/ex-series.R
 #' @author N. Frerebeau
 #' @docType methods
-#' @family time series tools
+#' @family tools
 #' @aliases start-method end-method
 #' @name start
 #' @rdname start
 NULL
 
-#' Sampling Times of Time Series
+#' Sampling Times
 #'
 #' Get the sampling times:
 #' * `time()` creates the vector of times at which a time series was sampled.
@@ -505,36 +579,17 @@ NULL
 #' @param calendar A [`TimeScale-class`] object specifying the target calendar
 #'  (see [calendar()]). If `NULL` (the default), *rata die* are returned.
 #' @return
-#'  A [`numeric`] vector.
+#'  A [`numeric`] vector of decimal years (if `calendar` is not `NULL`).
 #' @example inst/examples/ex-series.R
 #' @author N. Frerebeau
 #' @docType methods
-#' @family time series tools
+#' @family tools
 #' @aliases time-method frequency-method
 #' @name time
 #' @rdname time
 NULL
 
-#' Duration of Time Series
-#'
-#' Get the duration.
-#' @param x A [`TimeSeries-class`] object.
-#' @param calendar A [`TimeScale-class`] object specifying the target calendar
-#'  (see [calendar()]). If `NULL` (the default), *rata die* are returned.
-#' @param ... Currently not used.
-#' @return
-#'  A [`numeric`] vector.
-#' @example inst/examples/ex-series.R
-#' @author N. Frerebeau
-#' @docType methods
-#' @family time series tools
-#' @aliases span-method
-setGeneric(
-  name = "span",
-  def = function(x, ...) standardGeneric("span")
-)
-
-#' Time Series Windows
+#' Time Windows
 #'
 #' Extracts the subset of the object `x` observed between the times `start` and
 #' `end` (expressed in *rata die*).
@@ -548,43 +603,68 @@ setGeneric(
 #' @example inst/examples/ex-window.R
 #' @author N. Frerebeau
 #' @docType methods
-#' @family time series tools
+#' @family tools
 #' @aliases window-method
 #' @name window
 #' @rdname window
 NULL
 
-#' Coerce to a Data Frame
+#' Duration
 #'
-#' @param x A [`TimeSeries-class`] object.
+#' Get the duration of time series or intervals.
+#' @param x A [`TimeSeries-class`] or a [`TimeIntervals-class`] object.
 #' @param calendar A [`TimeScale-class`] object specifying the target calendar
 #'  (see [calendar()]). If `NULL` (the default), *rata die* are returned.
-#' @param ... Further parameters to be passed to [data.frame()].
+#' @param ... Currently not used.
 #' @return
-#'  A long [`data.frame`] with the following columns:
-#'  \describe{
-#'   \item{`time`}{The (decimal) years at which the time series was sampled.}
-#'   \item{`series`}{The name of the time series.}
-#'   \item{`variable`}{The name of the variables.}
-#'   \item{`value`}{The observed value.}
-#'  }
-#' @example inst/examples/ex-series.R
+#'  A [`numeric`] vector of years.
+#' @example inst/examples/ex-duration.R
 #' @author N. Frerebeau
 #' @docType methods
-#' @family time series tools
-#' @name data.frame
-#' @rdname data.frame
-NULL
+#' @family tools
+#' @aliases span-method
+setGeneric(
+  name = "span",
+  def = function(x, ...) standardGeneric("span")
+)
 
-#' Plot Time Series
+#' Time Overlap
 #'
-#' @param x A [`TimeSeries-class`] object.
+#' Computes the length of overlap of time intervals.
+#' @param x A [`TimeIntervals-class`] object.
+#' @param calendar A [`TimeScale-class`] object specifying the target calendar
+#'  (see [calendar()]). If `NULL` (the default), *rata die* are returned.
+#' @param ... Currently not used.
+#' @details
+#'  The overlap of two time intervals is a difference between the minimum value
+#'  of the two upper boundaries and the maximum value of the two lower
+#'  boundaries, plus 1.
+#' @return
+#'  A symmetric `numeric` [`matrix`] of years.
+#' @example inst/examples/ex-intervals.R
+#' @author N. Frerebeau
+#' @docType methods
+#' @family tools
+#' @aliases overlap-method
+setGeneric(
+  name = "overlap",
+  def = function(x, ...) standardGeneric("overlap")
+)
+
+# Plot =========================================================================
+#' Plot Time Series and Time Intervals
+#'
+#' @param x A [`TimeSeries-class`] or a [`TimeIntervals-class`] object.
 #' @param facet A [`character`] string specifying whether the series should be
 #'  plotted separately (with a common time axis) or on a single plot?
 #'  It must be one of "`multiple`" or "`single`". Any unambiguous substring can
 #'  be given.
 #' @param calendar A [`TimeScale-class`] object specifying the target calendar
 #'  (see [calendar()]).
+#' @param sort A [`logical`] scalar: should the data be sorted in chronological
+#'  order?
+#' @param decreasing A [`logical`] scalar: should the sort order be decreasing?
+#'  Only used if `sort` is `TRUE`.
 #' @param panel A [`function`] in the form `function(x, y, ...)`
 #'  which gives the action to be carried out in each panel of the display.
 #'  The default is [graphics::lines()].
